@@ -1,6 +1,6 @@
 #' Least Squares Regression for Continuous Dependent Variables
 #'
-#' Vignette: \url{http://docs.zeligproject.org/en/latest/zelig-ls.html}
+#' Vignette: \url{http://docs.zeligproject.org/articles/zelig_ls.html}
 #' @import methods
 #' @export Zelig-ls
 #' @exportClass Zelig-ls
@@ -26,12 +26,13 @@ zls$methods(
 )
 
 zls$methods(
-  zelig = function(formula, data, ..., weights = NULL, by = NULL, bootstrap = FALSE) {
+  zelig = function(formula, data, ..., weights = NULL, by = NULL,
+      bootstrap = FALSE) {
     .self$zelig.call <- match.call(expand.dots = TRUE)
     .self$model.call <- .self$zelig.call
     callSuper(formula = formula, data = data, ...,
               weights = weights, by = by, bootstrap = bootstrap)
-    
+
     # Automated Background Test Statistics and Criteria
     rse <- lapply(.self$zelig.out$z.out, (function(x) vcovHC(x, type = "HC0")))
     rse.se <- sqrt(diag(rse[[1]]))                 # Needs to work with "by" argument
@@ -44,9 +45,11 @@ zls$methods(
 zls$methods(
   param = function(z.out, method="mvn") {
     if(identical(method,"mvn")){
-      return(list(simparam=mvrnorm(.self$num, coef(z.out), vcov(z.out)), simalpha=rep( summary(z.out)$sigma, .self$num) )  )
+      return(list(simparam = mvrnorm(.self$num, coef(z.out), vcov(z.out)),
+                  simalpha = rep( summary(z.out)$sigma, .self$num) )  )
     } else if(identical(method,"point")){
-      return(list(simparam=t(as.matrix(coef(z.out))), simalpha=summary(z.out)$sigma))
+      return(list(simparam = t(as.matrix(coef(z.out))),
+             simalpha=summary(z.out)$sigma))
     } else {
       stop("param called with method argument of undefined type.")
     }
@@ -56,7 +59,8 @@ zls$methods(
 zls$methods(
   qi = function(simparam, mm) {
     ev <- simparam$simparam %*% t(mm)
-    pv <- as.matrix(rnorm(n=length(ev), mean=ev, sd=simparam$simalpha), nrow=length(ev), ncol=1)
+    pv <- as.matrix(rnorm(n=length(ev), mean=ev, sd=simparam$simalpha),
+                    nrow=length(ev), ncol=1)
     return(list(ev = ev, pv = pv))
   }
 )
@@ -68,24 +72,24 @@ zls$methods(
         sigma2 <- sigma
         -1/2 * (sum(log(sigma2) + (y -(X%*%beta))^2/sigma2))
     }
-    
+
     getVb<-function(Dboot){
       Dbar <- matrix(apply(Dboot,2,mean),nrow=B, ncol=length(Dhat), byrow=TRUE)
       Diff <- Dboot - Dbar
       Vb <- (t(Diff) %*% Diff) / (nrow(Dboot)-1)
       return(Vb)
     }
-    
+
     getSigma<-function(lm.obj){
       return(sum(lm.obj$residuals^2)/(nrow(model.matrix(lm.obj))-ncol(model.matrix(lm.obj))))
     }
-    
+
     D.est<-function(formula,data){
       lm1 <- lm(formula,data, y=TRUE)
       mm <- model.matrix(lm1)
       y <- lm1$y
       sigma <- getSigma(lm1)
-    
+
       grad <- apply(cbind(y,mm),1,function(x) numericGradient(ll.normal.bsIM, lm1$coefficients, y=x[1], X=x[2:length(x)], sigma=sigma))
       meat <- grad%*%t(grad)
       bread <- -solve(vcov(lm1))
@@ -98,7 +102,7 @@ zls$methods(
         mm <- model.matrix(lm1)
         y <- lm1$y
         sigma <- getSigma(lm1)
-        
+
         grad <- apply(cbind(y,mm),1,function(x) numericGradient(ll.normal.bsIM, lm1$coefficients, y=x[1], X=x[2:length(x)], sigma=sigma))
         meat <- grad%*%t(grad)
         bread <- -solve(vcov(lm1))
@@ -106,7 +110,7 @@ zls$methods(
 
         muB<-lm1$fitted.values
         DB <- matrix(NA, nrow=B2, ncol=length(Dhat))
-            
+
         for(j in 1:B2){
           yB2 <- rnorm(nrow(data), muB, sqrt(sigma))
           lm1B2 <- lm(yB2 ~ mm-1)
@@ -122,14 +126,14 @@ zls$methods(
 
         return(list(Dhat=Dhat,T=T))
     }
-    
+
     Dhat <- D.est(formula=.self$formula, data=.self$data)
     lm1 <- lm(formula=.self$formula, data=.self$data)
     mu <- lm1$fitted.values
     sigma <- getSigma(lm1)
     n <- length(mu)
     yname <- all.vars(.self$formula[[2]])
-    
+
     Dboot <- matrix(NA, nrow=B, ncol=length(Dhat))
     bootdata<-data
     for(i in 1:B){
@@ -143,7 +147,7 @@ zls$methods(
     Vb <- getVb(Dboot)
     omega <- t(Dhat) %*% solve(Vb) %*% Dhat
     pb = (B+1-sum(T< as.numeric(omega)))/(B+1)
-    
+
     .self$test.statistics$gim <- list(stat=omega, pval=pb)
 
     # When method used, add to references
