@@ -1,6 +1,6 @@
 #' Quantile Regression for Continuous Dependent Variables
 #'
-#' Vignette: \url{http://docs.zeligproject.org/en/latest/zelig-quantile.html}
+#' Vignette: \url{http://docs.zeligproject.org/articles/zelig_quantile.html}
 #' @import methods
 #' @export Zelig-quantile
 #' @exportClass Zelig-quantile
@@ -31,41 +31,63 @@ zquantile$methods(
 )
 
 zquantile$methods(
-  zelig = function(formula, data, ..., weights = NULL, by = NULL, bootstrap = FALSE) {
+  zelig = function(formula, data, ..., weights = NULL, by = NULL,
+                   bootstrap = FALSE) {
 
-    localBy <- by # avoids CRAN warning about deep assignment from formula existing separately as argument and field
-    localData <- data # avoids CRAN warning about deep assignment from formula existing separately as argument and field
+    # avoids CRAN warning about deep assignment from formula existing separately as argument and field
+    localBy <- by
+    # avoids CRAN warning about deep assignment from formula existing separately as argument and field
+    localData <- data
     .self$zelig.call <- match.call(expand.dots = TRUE)
     .self$model.call <- match.call(expand.dots = TRUE)
-    if (!is.null(.self$model.call$tau)) {
-      .self$tau <- eval(.self$model.call$tau)
-      if (length(.self$tau)) {
-        localDataata <- rbind_all(lapply(eval(.self$tau),
-                                 function(tau) cbind(tau, localData)))
-        localBy <- cbind("tau", localBy)
-      }
-    }
-    else
-      .self$tau <- 0.5
-    callSuper(formula = formula, data = localData, ..., weights = weights, by = localBy, bootstrap = bootstrap)
 
-    rse <- lapply(.self$zelig.out$z.out, (function(x)
-                    quantreg::summary.rq(x, se = "nid", cov = TRUE)$cov))
+    if (!is.null(.self$model.call$tau)) {
+        if (length(eval(.self$model.call$tau)) > 1) {
+            stop('tau argument only accepts 1 value.\nZelig is using only the first value.',
+                    call. = FALSE)
+        } else
+            .self$tau <- eval(.self$model.call$tau)
+#        if (length(.self$tau) > 1) {
+#            localData <- bind_rows(lapply(eval(.self$tau),
+#                                      function(tau) cbind(tau, localData)))
+#          #  localBy <- cbind("tau", localBy)
+#        }
+    } else
+        .self$tau <- 0.5
+
+    callSuper(formula = formula, data = localData, ..., weights = weights,
+                by = localBy, bootstrap = bootstrap)
+
+    rq_summaries <- lapply(.self$zelig.out$z.out, (function(x)
+                            summary(x, se = "nid", cov = TRUE)))
+
+    rse <- lapply(rq_summaries, (function(x)
+                if (length(rq_summaries) > 1)
+                    lapply(x, function(y) y$cov)
+                else x$cov
+        ))
+
+#    rse <- lapply(.self$zelig.out$z.out, (function(x)
+#        quantreg::summary.rq(x, se = "nid", cov = TRUE)$cov))
+
+#    rse <- lapply(.self$zelig.out$z.out,
+#        (function(x) {
+#            full <- quantreg::summary.rq(x, se = "nid", cov = TRUE)$cov
+#        })
+#    )
     .self$test.statistics<- list(robust.se = rse)
-  }
-)
+})
 
 zquantile$methods(
-  param = function(z.out, method="mvn") {
+  param = function(z.out, method = "mvn") {
     object <- z.out
     if(identical(method,"mvn")){
-      rq.sum <- summary.rq(object, cov = TRUE, se = object$se)
-      return(mvrnorm(n = .self$num, mu = object$coef, Sigma = rq.sum$cov))
-    }else if(identical(method,"point")){
-      return(t(as.matrix(object$coef)))
+        rq.sum <- summary(object, cov = TRUE, se = object$se)
+        return(mvrnorm(n = .self$num, mu = object$coef, Sigma = rq.sum$cov))
+    } else if(identical(method,"point")){
+        return(t(as.matrix(object$coef)))
     }
-  }
-)
+})
 
 zquantile$methods(
   qi = function(simparam, mm) {
