@@ -31,13 +31,13 @@ Mode <- function (x) {
 #' @author Matt Owen
 
 Median <- function (x, na.rm=NULL) {
-  v <- ifelse(is.numeric(x),
-              median(x),
-              levels(x)[ceiling(median(as.numeric(x)))]
-  )
-  if (is.ordered(x))
-    v <- factor(v, levels(x))
-  v
+    v <- ifelse(is.numeric(x),
+                median(x),
+                levels(x)[ceiling(median(as.numeric(x)))]
+    )
+    if (is.ordered(x))
+        v <- factor(v, levels(x))
+    v
 }
 
 #' Create a table, but ensure that the correct
@@ -51,16 +51,16 @@ Median <- function (x, na.rm=NULL) {
 #' @author Matt Owen
 
 table.levels <- function (x, levels, ...) {
-  # if levels are not explicitly set, then
-  # search inside of x
-  if (missing(levels)) {
-    levels <- attr(x, 'levels')
-    table(factor(x, levels=levels), ...)
-  }
-  # otherwise just do the normal thing
-  else {
-    table(factor(x, levels=levels), ...)
-  }
+    # if levels are not explicitly set, then
+    # search inside of x
+    if (missing(levels)) {
+        levels <- attr(x, 'levels')
+        table(factor(x, levels=levels), ...)
+    }
+    # otherwise just do the normal thing
+    else {
+        table(factor(x, levels=levels), ...)
+    }
 }
 
 #' Compute central tendancy as approrpriate to data type
@@ -69,12 +69,12 @@ table.levels <- function (x, levels, ...) {
 #' @export
 
 avg <- function(val) {
-  if (is.numeric(val))
-    mean(val)
-  else if (is.ordered(val))
-    Median(val)
-  else
-    Mode(val)
+    if (is.numeric(val))
+        mean(val)
+    else if (is.ordered(val))
+        Median(val)
+    else
+        Mode(val)
 }
 
 #' Set new value of a factor variable, checking for existing levels
@@ -83,10 +83,10 @@ avg <- function(val) {
 #' @return a factor variable with a value \code{val} and the same levels
 #' @keywords internal
 setfactor <- function (fv, v) {
-  lev <- levels(fv)
-  if (!v %in% lev)
-    stop("Wrong factor")
-  return(factor(v, levels = lev))
+    lev <- levels(fv)
+    if (!v %in% lev)
+        stop("Wrong factor")
+    return(factor(v, levels = lev))
 }
 
 #' Set new value of a variable as approrpriate to data type
@@ -95,18 +95,18 @@ setfactor <- function (fv, v) {
 #' @return a variable of the same type with a value \code{val}
 #' @keywords internal
 setval <- function(val, newval) {
-  if (is.numeric(val))
-    newval
-  else if (is.ordered(val))
-    newval
-  else if (is.logical(val))
-    newval
-  else {
-    lev <- levels(val)
-    if (!newval %in% lev)
-      stop("Wrong factor", call. = FALSE)
-    return(factor(newval, levels = lev))
-  }
+    if (is.numeric(val))
+        newval
+    else if (is.ordered(val))
+        newval
+    else if (is.logical(val))
+        newval
+    else {
+        lev <- levels(val)
+        if (!newval %in% lev)
+            stop("Wrong factor", call. = FALSE)
+        return(factor(newval, levels = lev))
+    }
 }
 
 
@@ -144,7 +144,7 @@ reduce = function(dataset, s, formula, data, avg = avg) {
         ma <- m[!is.na(m)]
         if (!all(complete.cases(m))) {
             w <- paste("Variable '", names(s[is.na(m)]), "' not in data set.\n",
-                     sep = "")
+                       sep = "")
             stop(w, call. = FALSE)
         }
         for (i in seq(n[ma])) {
@@ -163,13 +163,13 @@ reduce = function(dataset, s, formula, data, avg = avg) {
 #' @keywords internal
 #' @author Christine Choirat
 statmat <- function(qi) {
-  m <- t(apply(qi, 2, quantile, c(.5, .025, .975), na.rm = TRUE))
-  n <- matrix(apply(qi, 2, mean, na.rm = TRUE))
-  colnames(n) <- "mean"
-  o <- matrix(apply(qi, 2, sd, na.rm = TRUE))
-  colnames(o) <- "sd"
-  p <- cbind(n, o, m)
-  return(p)
+    m <- t(apply(qi, 2, quantile, c(.5, .025, .975), na.rm = TRUE))
+    n <- matrix(apply(qi, 2, mean, na.rm = TRUE))
+    colnames(n) <- "mean"
+    o <- matrix(apply(qi, 2, sd, na.rm = TRUE))
+    colnames(o) <- "sd"
+    p <- cbind(n, o, m)
+    return(p)
 }
 
 #' Describe Here
@@ -198,10 +198,10 @@ statlevel <- function(qi, num) {
 #' @keywords internal
 #' @author Christine Choirat
 stat <- function(qi, num) {
-  if (is.null(attr(qi, "levels")))
-    return(statmat(qi))
-  else
-    return(statlevel(qi, num))
+    if (is.null(attr(qi, "levels")))
+        return(statmat(qi))
+    else
+        return(statlevel(qi, num))
 }
 
 #' Generate Formulae that Consider Clustering
@@ -212,15 +212,15 @@ stat <- function(qi, num) {
 #' @param cluster a vector
 #' @return a formula object describing clustering
 cluster.formula <- function (formula, cluster) {
-  # Convert LHS of formula to a string
-  lhs <- deparse(formula[[2]])
-  cluster.part <- if (is.null(cluster))
-    # NULL values require
-    sprintf("cluster(1:nrow(%s))", lhs)
-  else
-    # Otherwise we trust user input
-    sprintf("cluster(%s)", cluster)
-  update(formula, paste(". ~ .", cluster.part, sep = " + "))
+    # Convert LHS of formula to a string
+    lhs <- deparse(formula[[2]])
+    cluster.part <- if (is.null(cluster))
+        # NULL values require
+        sprintf("cluster(1:nrow(%s))", lhs)
+    else
+        # Otherwise we trust user input
+        sprintf("cluster(%s)", cluster)
+    update(formula, paste(". ~ .", cluster.part, sep = " + "))
 }
 
 
@@ -247,7 +247,7 @@ zelig_mutate <- function (.data, ...)
 #' @keywords internal
 
 expand_grid_setrange <- function(x) {
-#    m <- expand.grid(x)
+    #    m <- expand.grid(x)
     set_lengths <- unlist(lapply(x, length))
     unique_set_lengths <- unique(as.vector(set_lengths))
 
@@ -310,7 +310,7 @@ to_zelig_mi <- function (...) {
     # Labelling
     names(imputations) <- paste0("imp", 1:length(imputations))
 
-    # Ensure that everything is data.frame
+    # Ensure that everything is a data.frame
     for (k in length(imputations):1) {
         if (!is.data.frame(imputations[[k]])){
             imputations[[k]] <- NULL
@@ -320,11 +320,11 @@ to_zelig_mi <- function (...) {
 
     if(length(imputations) < 1){
         stop("The resulting object contains no data.frames, and as such is not a valid multiple imputation object.",
-        call. = FALSE)
-      }
+             call. = FALSE)
+    }
     if(length(imputations) < 2){
         stop("The resulting object contains only one data.frame, and as such is not a valid multiple imputation object.",
-        call. = FALSE)
+             call. = FALSE)
     }
     class(imputations) <-c("mi", "list")
 
@@ -344,7 +344,8 @@ mi <- to_zelig_mi
 #'
 #' @param formula model formulae
 #' @param data data frame used in \code{formula}
-#' @param FUN character string of the transformation function
+#' @param FUN character string of the transformation function. Currently
+#'   supports \code{factor} and \code{log}.
 #' @param check logical whether to just check if a formula contains an
 #'   internally called transformation and return \code{TRUE} or \code{FALSE}
 #' @param f_out logical whether to return the converted formula
@@ -352,16 +353,25 @@ mi <- to_zelig_mi
 #'   \code{f_out} must be missing
 #'
 #' @author Christopher Gandrud
-#' @internal
+#' @keywords internal
 
 transformer <- function(formula, data, FUN = 'log', check, f_out, d_out) {
 
+    if (!missing(data)) {
+        if (is.data.frame(data))
+            is_df <- TRUE
+        else if (!is.data.frame(data) & is.list(data))
+            is_df <- FALSE
+        else
+            stop('data must be either a data.frame or a list', call. = FALSE)
+    }
+
     if (FUN == 'as.factor') FUN_temp <- 'as\\.factor'
     else FUN_temp <- FUN
-    FUN_str <- sprintf('%s\\(', FUN_temp)
+    FUN_str <- sprintf('%s.*\\(', FUN_temp)
 
     f <- as.character(formula)[3]
-    f_split <- unlist(strsplit(f, split = ' '))
+    f_split <- unlist(strsplit(f, split = '\\+'))
     to_transform <- grep(pattern = FUN_str, f_split)
 
     if (!missing(check)) {
@@ -370,25 +380,74 @@ transformer <- function(formula, data, FUN = 'log', check, f_out, d_out) {
     }
 
     if (length(to_transform) > 0) {
-        to_transform_raw <- f_split[to_transform]
-        to_transform_plain <- gsub(FUN_str, '', to_transform_raw)
+        to_transform_raw <- trimws(f_split[to_transform])
+        if (FUN == 'factor')
+            to_transform_raw <- gsub('^as\\.', '', to_transform_raw)
+        to_transform_plain_args <- gsub(FUN_str, '', to_transform_raw)
+        to_transform_plain <- gsub(',\\(.*)', '', to_transform_plain_args)
         to_transform_plain <- gsub('\\)', '', to_transform_plain)
+        to_transform_plain <- trimws(gsub(',.*', '', to_transform_plain))
 
-        if (!all(to_transform_plain %in% names(data)))
-            stop('Unable to find variable to transform.')
+        if (is_df)
+            not_in_data <- !all(to_transform_plain %in% names(data))
+        else if (!isTRUE(is_df))
+            not_in_data <- !all(to_transform_plain %in% names(data[[1]]))
+        if (not_in_data) stop('Unable to find variable to transform.')
 
         if (!missing(f_out)) {
             f_split[to_transform] <- to_transform_plain
-            f_comb <- paste(f_split, collapse = ' ')
-            dv <- gsub('\\(\\)', '', formula[2])
-            f_new <- paste(dv, '~', f_comb, collapse = ' ')
-            f_out <- as.formula(f_new)
+            rhs <- paste(f_split, collapse = ' + ')
+            lhs <- gsub('\\(\\)', '', formula[2])
+            f_new <- paste(lhs, '~', rhs)
+            f_out <- as.Formula(f_new)
             return(f_out)
         }
-        else if (d_out) {
-            for (i in to_transform_plain)
-              data[, i] <- eval(parse(text = sprintf('%s(data[, i])',
-                                                     FUN)))
+        else if (!missing(d_out)) {
+
+            transformer_fun <- trimws(gsub('\\(.*', '', to_transform_raw))
+
+            transformer_args_str <- gsub('\\)', '', to_transform_plain_args)
+            transformer_args_list <- list()
+            for (i in seq_along(transformer_args_str)) {
+                args_temp <- unlist(strsplit(gsub(' ', '' ,
+                                                  transformer_args_str[i]), ','))
+                if (is_df)
+                    args_temp[1] <- sprintf('data[, "%s"]', args_temp[1])
+                else if (!isTRUE(is_df))
+                    args_temp[1] <- sprintf('data[[h]][, "%s"]', args_temp[1])
+                arg_names <- gsub('\\=.*', '', args_temp)
+                arg_names[1] <- 'x'
+                args_temp <- gsub('.*\\=', '', args_temp)
+
+                args_temp_list <- list()
+                if (is_df) {
+                    for (u in seq_along(args_temp))
+                        args_temp_list[[u]] <- eval(parse(text = args_temp[u]))
+                }
+                else if (!isTRUE(is_df)) {
+                    for (h in seq_along(data)) {
+                        temp_list <- list()
+                        for (u in seq_along(args_temp)) {
+                            temp_list[[u]] <- eval(parse(text = args_temp[u]))
+                            names(temp_list)[u] <- arg_names[u]
+                        }
+                        args_temp_list[[h]] <- temp_list
+                    }
+                }
+                if (is_df) {
+                    names(args_temp_list) <- arg_names
+                    data[, to_transform_plain[i]] <- do.call(
+                        what = transformer_fun[i],
+                        args = args_temp_list)
+                }
+                else if (!isTRUE(is_df)) {
+                    for (j in seq_along(data)) {
+                        data[[j]][, to_transform_plain[i]] <- do.call(
+                            what = transformer_fun[i],
+                            args = args_temp_list[[j]])
+                    }
+                }
+            }
             return(data)
         }
     }
@@ -399,12 +458,11 @@ transformer <- function(formula, data, FUN = 'log', check, f_out, d_out) {
 }
 
 
-
 #' Remove package names from fitted model object calls.
 #'
 #' Enables \code{\link{from_zelig_model}} output to work with stargazer.
 #' @param x a fitted model object result
-#' @internal
+#' @keywords internal
 
 strip_package_name <- function(x) {
     call_temp <- gsub('^.*(?=(::))', '', x$call[1], perl = TRUE)
@@ -415,7 +473,7 @@ strip_package_name <- function(x) {
 
 #' Extract p-values from a fitted model object
 #' @param x a fitted Zelig object
-#' @internal
+#' @keywords internal
 
 p_pull <- function(x) {
     p_values <- summary(x)$coefficients
@@ -429,24 +487,28 @@ p_pull <- function(x) {
 
 #' Extract standard errors from a fitted model object
 #' @param x a fitted Zelig object
-#' @internal
+#' @keywords internal
 
 se_pull <- function(x) {
     se <- summary(x)$coefficients[, "Std. Error"]
     return(se)
 }
 
-#' Drop intercept columns from a data frame of fitted values
+#' Drop intercept columns or values from a data frame or named vector,
+#'   respectively
 #'
-#' @param x a data frame
-#' @internal
+#' @param x a data frame or named vector
+#' @keywords internal
 
 rm_intercept <- function(x) {
     intercept_names <- c('(Intercept)', 'X.Intercept.', '(Intercept).*')
     names_x <- names(x)
     if (any(intercept_names %in% names(x))) {
         keep <- !(names(x) %in% intercept_names)
-        x <- data.frame(x[, names_x[keep]])
+        if (is.data.frame(x))
+            x <- data.frame(x[, names_x[keep]])
+        else if (is.vector(x))
+            x <- x[keep]
         names(x) <- names_x[keep]
     }
     return(x)
@@ -566,5 +628,16 @@ combine_coef_se <- function(obj, out_type = 'matrix', bagging = FALSE,
     }
     else if (!(obj$mi || obj$bootstrap))
         stop('No multiply imputed or bootstrapped estimates found. So no need to combine.',
-            call. = FALSE)
+             call. = FALSE)
+}
+
+#' Find vcov for GEE models
+#'
+#' @param obj a \code{geeglm} class object.
+
+vcov_gee <- function(obj) {
+    if (!("geeglm" %in% class(obj)))
+        stop('Not a geeglm class object', call. = FALSE)
+    out <- obj$geese$vbeta
+    return(out)
 }
