@@ -1,7 +1,11 @@
+library(AER)
+library(Amelia)
+library(dplyr)
+library(geepack)
+library(MatchIt)
+library(survey)
 library(testthat)
 library(Zelig)
-library(survey)
-library(dplyr)
 
 set.seed(123)
 test_check("Zelig")
