@@ -2,6 +2,6 @@
 
 test_that('REQUIRE TEST normalsurvey Monte Carlo', {
     z <- znormalsurvey$new()
-    test <- z$mcunit(plot = FALSE)
-    expect_true(test)
+    test.normalsurvey <- z$mcunit(plot = FALSE)
+    expect_true(test.normalsurvey)
 })
\ No newline at end of file
